==> cramr_ui_lib-0.0.17.tar.gz: lib/routes/verb_indicative_study_form_appbar.dart <==
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/routes/verb_selection_route.dart';
import 'package:cramr_ui_lib/settings/settings_view.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

/// Generic AppBar delegate for study screens.
class VerbIndicativeStudyFormAppbar {
  AppBar asWidget(BuildContext context) {
    return AppBar(
      key: UniqueKey(),
      title: _titleCell(context),
      actions: [
        _homeIcon(context),
        _settingsIcon(context),
      ],
    );
  }

  IconButton _settingsIcon(BuildContext context) {
    return IconButton(
        key: const Key('settingsButton'),
        icon: const Icon(Icons.settings),
        onPressed: () {
          Navigator.pushNamed(context, SettingsView.routeName);
        });
  }

  Widget _titleCell(BuildContext context) {
    return Consumer<VerbTestModel>(builder: (context, testModel, child) {
      return Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        mainAxisAlignment: MainAxisAlignment.start,
        children: [
          Text(
            "Vervoeging ${testModel.verb.infinitive}",
            key: Key("Vervoeging ${testModel.verb.infinitive}"),
            textAlign: TextAlign.left,
          ),
          Text(testModel.verb.translation,
              key: Key("vertaling ${testModel.verb.infinitive}"),
              textAlign: TextAlign.left,
              style: const TextStyle(
                  fontSize: 15,
                  fontFamily: 'Roboto',
                  fontStyle: FontStyle.italic)),
        ],
      );
    });
  }

  IconButton _homeIcon(BuildContext context) {
    return IconButton(
        key: const Key('home_button'),
        onPressed: () {
          final VerbTestModel testModel =
              Provider.of<VerbTestModel>(context, listen: false);
          testModel.reset();
          Navigator.restorablePopAndPushNamed(
              context, VerbSelectionRoute.routeName);
        },
        icon: const Icon(Icons.home));
  }
}

==> cramr_ui_lib-1.0.2.tar.gz: lib/routes/verb_indicative_study_form_appbar.dart <==
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/routes/verb_selection_route.dart';
import 'package:cramr_ui_lib/settings/settings_view.dart';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

/// Generic AppBar delegate for study screens.
class VerbIndicativeStudyFormAppbar {
  AppBar asWidget(BuildContext context) {
    return AppBar(
      key: UniqueKey(),
      title: _titleCell(context),
      actions: [
        _homeIcon(context),
        _settingsIcon(context),
      ],
    );
  }

  IconButton _settingsIcon(BuildContext context) {
    return IconButton(
        key: const Key('settingsButton'),
        icon: const Icon(Icons.settings),
        onPressed: () {
          Navigator.pushNamed(context, SettingsView.routeName);
        });
  }

  Widget _titleCell(BuildContext context) {
    return Consumer<VerbTestModel>(builder: (context, testModel, child) {
      return Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        mainAxisAlignment: MainAxisAlignment.start,
        children: [
          Text(
            "Vervoeging ${testModel.infinitive}",
            key: Key("Vervoeging ${testModel.infinitive}"),
            textAlign: TextAlign.left,
          ),
          Text(testModel.translation,
              key: Key("vertaling ${testModel.infinitive}"),
              textAlign: TextAlign.left,
              style: const TextStyle(
                  fontSize: 15,
                  fontFamily: 'Roboto',
                  fontStyle: FontStyle.italic)),
        ],
      );
    });
  }

  IconButton _homeIcon(BuildContext context) {
    return IconButton(
        key: const Key('home_button'),
        onPressed: () {
          final VerbTestModel testModel =
              Provider.of<VerbTestModel>(context, listen: false);
          testModel.reset();
          Navigator.restorablePopAndPushNamed(
              context, VerbSelectionRoute.routeName);
        },
        icon: const Icon(Icons.home));
  }
}
